@@ -13,8 +13,9 @@ use Types::Standard -types;
 
 use namespace::autoclean;
 
-use version;
-$File::Rotate::Simple::VERSION = version->declare('v0.2.2');
+our $VERSION = 'v0.2.3';
+
+# ABSTRACT: no-frills file rotation
 
 # RECOMMEND PREREQ: Class::Load::XS
 # RECOMMEND PREREQ: Ref::Util::XS
@@ -22,71 +23,6 @@ $File::Rotate::Simple::VERSION = version->declare('v0.2.2');
 
 our @EXPORT_OK = qw/ rotate_files /;
 
-=head1 NAME
-
-File::Rotate::Simple - no-frills file rotation
-
-=head1 SYNOPSIS
-
-  use File::Rotate::Simple qw/ rotate_files /;
-
-  rotate_files(
-      file => '/foo/bar/backup.tar.gz',
-      age  => 7,
-      max  => 30,
-  );
-
-  rotate_files(
-      files => [ qw{ /var/log/foo.log /var/log/bar.log } ],
-      max   => 7,
-  );
-
-or the legacy interface:
-
-  File::Rotate::Simple->rotate(
-      file => '/foo/bar/backup.tar.gz',
-      age  => 7,
-      max  => 30,
-  );
-
-or the object-oriented interface:
-
-  my $r = File::Rotate::Simple->new(
-      file => '/foo/bar/backup.tar.gz',
-      age  => 7,
-      max  => 30,
-  );
-
-  $r->rotate;
-
-
-=head1 DESCRIPTION
-
-This module implements simple file rotation.
-
-Files are renamed to have a numeric suffix, e.g. F<backup.tar.gz> is renamed to
-F<backup.tar.gz.1>.  Existing file numbers are incremented.
-
-If L</max> is specified, then any files with a larger numeric suffix
-are deleted.
-
-If L</age> is specified, then any files older than that number of days
-are deleted.
-
-Note that files with the extension C<0> are ignored.
-
-=for readme stop
-
-=head1 ATTRIBUTES
-
-=head2 C<age>
-
-The maximum age of files (in days), relative to the L</time>
-attribute.  Older files will be deleted.
-
-A value C<0> (default) means there is no maximum age.
-
-=cut
 
 has age => (
     is      => 'ro',
@@ -94,16 +30,6 @@ has age => (
     default => 0,
 );
 
-=head2 C<max>
-
-The maximum number of files to keep.  Numbered files larger than this
-will be deleted.
-
-A value of C<0> (default) means that there is no maximum number.
-
-Note that it does not track whether intermediate files are missing.
-
-=cut
 
 has max => (
     is      => 'ro',
@@ -111,21 +37,6 @@ has max => (
     default => 0,
 );
 
-=head2 C<file>
-
-The file to rotate. This can be a string or L<Path::Tiny> object.
-
-=head2 C<files>
-
-When L</rotate> is called as a constructor, you can specify an array
-reference of files to rotate:
-
-  File::Rotate::Simple->rotate(
-     files => \@files,
-     ...
-  );
-
-=cut
 
 has file => (
     is       => 'ro',
@@ -134,13 +45,6 @@ has file => (
     required => 1,
 );
 
-=head2 C<start_num>
-
-The starting number to use when rotating files. Defaults to C<1>.
-
-Added in v0.2.0.
-
-=cut
 
 has start_num => (
     is      => 'ro',
@@ -148,15 +52,6 @@ has start_num => (
     default => 1,
 );
 
-=head2 C<extension_format>
-
-The extension to add when rotating. This is a string that is passed to
-L<Time::Piece/strftime> with the following addition of the C<%#> code,
-which corresponds to the rotation number of the file.
-
-Added in v0.2.0.
-
-=cut
 
 has extension_format => (
     is      => 'ro',
@@ -164,37 +59,12 @@ has extension_format => (
     default => '.%#',
 );
 
-=head2 C<replace_extension>
-
-If defined, it replaces the extension with the one specified by
-L</extension_format> rather than appending it.  Use this when you want
-to preserve the existing extension in a rotated backup, e.g.
-
-    my $r = File::Rotate::Simple->new(
-        file              => 'myapp.log',
-        extension_format  => '.%#.log',
-        replace_extension => '.log',
-    );
-
-will rotate the log as F<myapp.1.log>.
-
-Added in v0.2.0.
-
-=cut
 
 has replace_extension => (
     is  => 'ro',
     isa => Maybe[Str],
 );
 
-=head2 C<if_missing>
-
-When true, rotate the files even when L</file> is missing. True by
-default, for backwards compatability.
-
-Added in v0.2.0.
-
-=cut
 
 has if_missing => (
     is      => 'ro',
@@ -202,11 +72,6 @@ has if_missing => (
     default => 1,
 );
 
-=head2 C<touch>
-
-Touch L</file> after rotating.
-
-=cut
 
 has touch => (
     is      => 'ro',
@@ -214,36 +79,6 @@ has touch => (
     default => 0,
 );
 
-=head2 C<time>
-
-A time object corresponding to the time used for generating
-timestamped extensions in L</extension_format>.  It defaults to a
-L<Time::Piece> object with the current local time.
-
-You can specify an alternative time (including time zone) in the
-constructor, e.g.
-
-    use Time::Piece;
-
-    my $r = File::Rotate::Simple->new(
-        file              => 'myapp.log',
-        time              => gmtime(),
-        extension_format  => '.%Y%m%d',
-    );
-
-L<Time::Moment> and L<DateTime> objects can also be given.
-
-Unlike other attributes, L</time> is read-write, so that it can be
-updated between calls to L</rotate>:
-
-    use Time::Piece;
-
-    $r->time( localtime );
-    $r->rotate;
-
-Added in v0.2.0.
-
-=cut
 
 has time => (
     is      => 'rw',
@@ -256,15 +91,6 @@ has time => (
     },
 );
 
-=head1 METHODS
-
-=head2 C<rotate>
-
-Rotates the files.
-
-This can be called as a constructor.
-
-=cut
 
 sub rotate {
     my $self = shift;
@@ -324,19 +150,6 @@ sub rotate {
     # TODO: chmod/chown arguments
 }
 
-=begin internal
-
-=head1 INTERNAL METHODS
-
-=head2 C<_build_files_to_rotate>
-
-This method builds a reverse-ordered list of files to rotate.
-
-It gathers a list of files to rotate using L</_rotated_name> and
-L</file> and topoligically sorts them based on what the files will be
-renamed to.
-
-=cut
 
 sub _build_files_to_rotate {
     my ($self) = @_;
@@ -412,23 +225,6 @@ sub _build_files_to_rotate {
 
 }
 
-=head2 C<_rotated_name>
-
-  my $rotated = $r->_rotated_name( $index );
-
-This method generates a L<Path::Tiny> object of the rotated filename
-from the L</file>, L</extension_format>, and L</replace_extension>
-attributes, using the C<$index> (a positive integer).
-
-For example, given the default values and a L</file> called
-F</var/log/myapp.log> and C<$index = 12>, it will return the file
-F</var/log/myapp.log.12>.
-
-If the L</extension_format> refers to formats other than C<%#> (for
-the C<$index>), then it will use the L</time> to generate the new file
-name.
-
-=cut
 
 sub _rotated_name {
     my ($self, $index) = @_;
@@ -457,6 +253,216 @@ sub _rotated_name {
     }
 }
 
+
+sub rotate_files {
+  __PACKAGE__->rotate( @_ );
+}
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+File::Rotate::Simple - no-frills file rotation
+
+=head1 VERSION
+
+version v0.2.3
+
+=head1 SYNOPSIS
+
+  use File::Rotate::Simple qw/ rotate_files /;
+
+  rotate_files(
+      file => '/foo/bar/backup.tar.gz',
+      age  => 7,
+      max  => 30,
+  );
+
+  rotate_files(
+      files => [ qw{ /var/log/foo.log /var/log/bar.log } ],
+      max   => 7,
+  );
+
+or the legacy interface:
+
+  File::Rotate::Simple->rotate(
+      file => '/foo/bar/backup.tar.gz',
+      age  => 7,
+      max  => 30,
+  );
+
+or the object-oriented interface:
+
+  my $r = File::Rotate::Simple->new(
+      file => '/foo/bar/backup.tar.gz',
+      age  => 7,
+      max  => 30,
+  );
+
+  $r->rotate;
+
+=head1 DESCRIPTION
+
+This module implements simple file rotation.
+
+Files are renamed to have a numeric suffix, e.g. F<backup.tar.gz> is renamed to
+F<backup.tar.gz.1>.  Existing file numbers are incremented.
+
+If L</max> is specified, then any files with a larger numeric suffix
+are deleted.
+
+If L</age> is specified, then any files older than that number of days
+are deleted.
+
+Note that files with the extension C<0> are ignored.
+
+=for readme stop
+
+=head1 ATTRIBUTES
+
+=head2 C<age>
+
+The maximum age of files (in days), relative to the L</time>
+attribute.  Older files will be deleted.
+
+A value C<0> (default) means there is no maximum age.
+
+=head2 C<max>
+
+The maximum number of files to keep.  Numbered files larger than this
+will be deleted.
+
+A value of C<0> (default) means that there is no maximum number.
+
+Note that it does not track whether intermediate files are missing.
+
+=head2 C<file>
+
+The file to rotate. This can be a string or L<Path::Tiny> object.
+
+=head2 C<files>
+
+When L</rotate> is called as a constructor, you can specify an array
+reference of files to rotate:
+
+  File::Rotate::Simple->rotate(
+     files => \@files,
+     ...
+  );
+
+=head2 C<start_num>
+
+The starting number to use when rotating files. Defaults to C<1>.
+
+Added in v0.2.0.
+
+=head2 C<extension_format>
+
+The extension to add when rotating. This is a string that is passed to
+L<Time::Piece/strftime> with the following addition of the C<%#> code,
+which corresponds to the rotation number of the file.
+
+Added in v0.2.0.
+
+=head2 C<replace_extension>
+
+If defined, it replaces the extension with the one specified by
+L</extension_format> rather than appending it.  Use this when you want
+to preserve the existing extension in a rotated backup, e.g.
+
+    my $r = File::Rotate::Simple->new(
+        file              => 'myapp.log',
+        extension_format  => '.%#.log',
+        replace_extension => '.log',
+    );
+
+will rotate the log as F<myapp.1.log>.
+
+Added in v0.2.0.
+
+=head2 C<if_missing>
+
+When true, rotate the files even when L</file> is missing. True by
+default, for backwards compatability.
+
+Added in v0.2.0.
+
+=head2 C<touch>
+
+Touch L</file> after rotating.
+
+=head2 C<time>
+
+A time object corresponding to the time used for generating
+timestamped extensions in L</extension_format>.  It defaults to a
+L<Time::Piece> object with the current local time.
+
+You can specify an alternative time (including time zone) in the
+constructor, e.g.
+
+    use Time::Piece;
+
+    my $r = File::Rotate::Simple->new(
+        file              => 'myapp.log',
+        time              => gmtime(),
+        extension_format  => '.%Y%m%d',
+    );
+
+L<Time::Moment> and L<DateTime> objects can also be given.
+
+Unlike other attributes, L</time> is read-write, so that it can be
+updated between calls to L</rotate>:
+
+    use Time::Piece;
+
+    $r->time( localtime );
+    $r->rotate;
+
+Added in v0.2.0.
+
+=head1 METHODS
+
+=head2 C<rotate>
+
+Rotates the files.
+
+This can be called as a constructor.
+
+=begin internal
+
+=head1 INTERNAL METHODS
+
+=head2 C<_build_files_to_rotate>
+
+This method builds a reverse-ordered list of files to rotate.
+
+It gathers a list of files to rotate using L</_rotated_name> and
+L</file> and topoligically sorts them based on what the files will be
+renamed to.
+=head2 C<_rotated_name>
+
+  my $rotated = $r->_rotated_name( $index );
+
+This method generates a L<Path::Tiny> object of the rotated filename
+from the L</file>, L</extension_format>, and L</replace_extension>
+attributes, using the C<$index> (a positive integer).
+
+For example, given the default values and a L</file> called
+F</var/log/myapp.log> and C<$index = 12>, it will return the file
+F</var/log/myapp.log.12>.
+
+If the L</extension_format> refers to formats other than C<%#> (for
+the C<$index>), then it will use the L</time> to generate the new file
+name.
+
+
 =end internal
 
 =head1 EXPORTS
@@ -477,12 +483,6 @@ This is an optionally exported function for rotating files.
 
 Added in v0.2.0.
 
-=cut
-
-sub rotate_files {
-  __PACKAGE__->rotate( @_ );
-}
-
 =for readme continue
 
 =head1 SEE ALSO
@@ -499,54 +499,36 @@ The following modules have similar functionality:
 
 There are also several logging modueles that support log rotation.
 
+=head1 SOURCE
+
+The development version is on github at L<https://github.com/robrwo/File-Rotate-Simple>
+and may be cloned from L<git://github.com/robrwo/File-Rotate-Simple.git>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/robrwo/File-Rotate-Simple/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
-Robert Rothenberg, C<rrwo@cpan.org>
+Robert Rothenberg <rrwo@cpan.org>
 
-=head1 LICENSE AND COPYRIGHT
+=head1 CONTRIBUTOR
 
-Copyright 2017 Robert Rothenberg.
+=for stopwords Mohammad S Anwar
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
 
-L<http://www.perlfoundation.org/artistic_license_2_0>
+=head1 COPYRIGHT AND LICENSE
 
-=for readme stop
+This software is Copyright (c) 2018 by Robert Rothenberg.
 
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
+This is free software, licensed under:
 
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-=for readme continue
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-1;
